@@ -4,6 +4,7 @@ from datetime import date
 from imio.smartweb.core.config import EVENTS_URL
 from imio.smartweb.core.contents.rest.base import BaseEndpoint
 from imio.smartweb.core.contents.rest.base import BaseService
+from imio.smartweb.core.utils import hash_md5
 from plone.restapi.interfaces import IExpandableElement
 from zope.component import adapter
 from zope.interface import implementer
@@ -11,6 +12,20 @@ from zope.interface import Interface
 
 
 class BaseEventsEndpoint(BaseEndpoint):
+    def __call__(self):
+        results = super(BaseEventsEndpoint, self).__call__()
+        if not results.get("items"):
+            return results
+        for result in results["items"]:
+            modified_hash = hash_md5(result["modified"])
+            if result.get("image"):
+                self.convert_cached_image_scales(result, modified_hash)
+            for sub_content in result.get("items", []):
+                if sub_content["@type"] != "Image":
+                    continue
+                self.convert_cached_image_scales(sub_content, modified_hash)
+        return results
+
     @property
     def query_url(self):
         today = date.today().isoformat()
