@@ -4,11 +4,12 @@ from bs4 import BeautifulSoup
 from datetime import datetime
 from datetime import timedelta
 from freezegun import freeze_time
-from imio.smartweb.core.contents.sections.contact.view import formatted_schedule
-from imio.smartweb.core.contents.sections.contact.view import get_schedule_for_today
+from imio.smartweb.core.contents.sections.contact.utils import ContactProperties
+from imio.smartweb.core.contents.sections.contact.utils import formatted_schedule
+from imio.smartweb.core.contents.sections.contact.utils import get_schedule_for_today
+from imio.smartweb.core.contents.sections.views import SECTION_ITEMS_HASH_KEY
 from imio.smartweb.core.testing import IMIO_SMARTWEB_CORE_FUNCTIONAL_TESTING
 from imio.smartweb.core.testing import ImioSmartwebTestCase
-from imio.smartweb.core.tests.utils import clear_cache
 from imio.smartweb.core.tests.utils import get_json
 from plone import api
 from plone.app.testing import setRoles
@@ -16,6 +17,8 @@ from plone.app.testing import TEST_USER_ID
 from plone.app.testing import TEST_USER_NAME
 from plone.app.testing import TEST_USER_PASSWORD
 from plone.testing.zope import Browser
+from time import sleep
+from zope.annotation.interfaces import IAnnotations
 from zope.component import queryMultiAdapter
 
 import json
@@ -37,6 +40,7 @@ class TestSectionContact(ImioSmartwebTestCase):
             id="page",
         )
         self.json_contact = get_json("resources/json_contact_raw_mock.json")
+        self.json_contacts = get_json("resources/json_contacts_raw_mock.json")
         self.json_no_contact = get_json("resources/json_no_contact_raw_mock.json")
         self.json_contact_images = get_json(
             "resources/json_contact_images_raw_mock.json"
@@ -53,31 +57,27 @@ class TestSectionContact(ImioSmartwebTestCase):
         view = queryMultiAdapter((self.page, self.request), name="full_view")
         self.assertIn("My contact", view())
         contact_view = queryMultiAdapter((contact, self.request), name="view")
-        self.assertIsNone(contact_view.contact)
+        self.assertIsNone(contact_view.contacts())
         authentic_contact_uid = "2dc381f0fb584381b8e4a19c84f53b35"
-        contact.related_contact = authentic_contact_uid
+        contact.related_contacts = [authentic_contact_uid]
         contact_search_url = (
             "http://localhost:8080/Plone/@search?UID={}&fullobjects=1".format(
                 authentic_contact_uid
             )
         )
-        contact_images_url = "http://localhost:8080/Plone/{}/@search?portal_type=Image&path.depth=1&metadata_fields=image_scales".format(
+        contact_images_url = "http://localhost:8080/Plone/{}/@search?portal_type=Image&path.depth=1&metadata_fields=modified".format(
             authentic_contact_uid
         )
         m.get(contact_search_url, exc=requests.exceptions.ConnectTimeout)
-        clear_cache(self.request)
-        self.assertIsNone(contact_view.contact)
+        self.assertIsNone(contact_view.contacts())
         m.get(contact_search_url, status_code=404)
-        clear_cache(self.request)
-        self.assertIsNone(contact_view.contact)
+        self.assertIsNone(contact_view.contacts())
         m.get(contact_search_url, text=json.dumps(self.json_no_contact))
-        clear_cache(self.request)
-        self.assertIsNone(contact_view.contact)
-        self.assertEqual(contact_view.contact_type_class, "")
+        self.assertIsNone(contact_view.contacts())
         m.get(contact_search_url, text=json.dumps(self.json_contact))
-        clear_cache(self.request)
-        self.assertIsNotNone(contact_view.contact)
-        self.assertEqual(contact_view.contact_type_class, "contact-type-organization")
+        self.assertIsNotNone(contact_view.contacts())
+        json_contact = ContactProperties(self.json_contact.get("items")[0])
+        self.assertEqual(json_contact.contact_type_class, "contact-type-organization")
         self.assertNotIn("contact_titles", view())
         self.assertIn("contact_address", view())
         self.assertIn("contact_informations", view())
@@ -111,30 +111,66 @@ class TestSectionContact(ImioSmartwebTestCase):
 
         contact.visible_blocks = ["titles", "gallery"]
         m.get(contact_images_url, text=json.dumps(self.json_contact_images))
-        clear_cache(self.request)
         self.assertIn("contact_gallery", view())
-        self.assertEqual(len(contact_view.images[0]), 2)
 
-        m.get(contact_search_url, exc=requests.exceptions.ConnectTimeout)
-        clear_cache(self.request)
-        self.assertIsNone(contact_view.images)
-        m.get(contact_search_url, status_code=404)
-        clear_cache(self.request)
-        self.assertIsNone(contact_view.images)
-        m.get(contact_search_url, text=json.dumps(self.json_no_contact))
-        clear_cache(self.request)
-        self.assertIsNone(contact_view.images)
+        json_contact = ContactProperties(self.json_contact.get("items")[0])
+        images = json_contact.images(contact.image_scale, contact.nb_results_by_batch)
+        self.assertEqual(len(images[0]), 2)
 
-        m.get(contact_search_url, text=json.dumps(self.json_contact))
+        json_contact = ContactProperties(self.json_contact.get("items")[0])
         m.get(contact_images_url, text=json.dumps(self.json_no_image))
-        clear_cache(self.request)
-        self.assertIsNone(contact_view.images)
+        images = json_contact.images(contact.image_scale, contact.nb_results_by_batch)
+        self.assertIsNone(images)
+
         m.get(contact_images_url, status_code=404)
-        clear_cache(self.request)
-        self.assertIsNone(contact_view.images)
+        images = json_contact.images(contact.image_scale, contact.nb_results_by_batch)
+        self.assertIsNone(images)
+
         m.get(contact_images_url, exc=requests.exceptions.ConnectTimeout)
-        clear_cache(self.request)
-        self.assertIsNone(contact_view.images)
+        images = json_contact.images(contact.image_scale, contact.nb_results_by_batch)
+        self.assertIsNone(images)
+
+    @requests_mock.Mocker()
+    def test_sorted_contacts(self, m):
+        contact = api.content.create(
+            container=self.page,
+            type="imio.smartweb.SectionContact",
+            title="My contact",
+        )
+        contact_view = queryMultiAdapter((contact, self.request), name="view")
+        self.assertIsNone(contact_view.contacts())
+        authentic_contact_uid = [
+            "2dc381f0fb584381b8e4a19c84f53b35",
+            "af7bd1f547034b24a2e0da16c0ba0358",
+        ]
+        contact.related_contacts = authentic_contact_uid
+        uids = "&UID=".join(contact.related_contacts)
+        contact_search_url = (
+            "http://localhost:8080/Plone/@search?UID={}&fullobjects=1".format(uids)
+        )
+        m.get(contact_search_url, text=json.dumps(self.json_contacts))
+        self.assertIsNotNone(contact_view.contacts())
+        # contact_view.contacts()[0][0] : first contact of first bash
+        self.assertEqual(
+            contact.related_contacts[0], contact_view.contacts()[0][0].get("UID")
+        )
+
+        # Change sort order
+        authentic_contact_uid = [
+            "af7bd1f547034b24a2e0da16c0ba0358",
+            "2dc381f0fb584381b8e4a19c84f53b35",
+        ]
+        contact.related_contacts = authentic_contact_uid
+        uids = "&UID=".join(contact.related_contacts)
+        contact_search_url = (
+            "http://localhost:8080/Plone/@search?UID={}&fullobjects=1".format(uids)
+        )
+        m.get(contact_search_url, text=json.dumps(self.json_contacts))
+        self.assertIsNotNone(contact_view.contacts())
+        # contact_view.contacts()[0][0] : first contact of first bash
+        self.assertEqual(
+            contact.related_contacts[0], contact_view.contacts()[0][0].get("UID")
+        )
 
     def test_toggle_title_visibility(self):
         page = api.content.create(
@@ -190,17 +226,10 @@ class TestSectionContact(ImioSmartwebTestCase):
             title="My contact",
         )
         contact_view = queryMultiAdapter((contact, self.request), name="view")
-        self.assertIsNone(contact_view.get_opening_informations())
-        authentic_contact_uid = "2dc381f0fb584381b8e4a19c84f53b35"
-        contact.related_contact = authentic_contact_uid
-        contact_search_url = (
-            "http://localhost:8080/Plone/@search?UID={}&fullobjects=1".format(
-                authentic_contact_uid
-            )
+        json_contact = contact_view.get_contact_properties(
+            self.json_contact.get("items")[0]
         )
-        m.get(contact_search_url, text=json.dumps(self.json_contact))
-        clear_cache(self.request)
-        self.assertIsNotNone(contact_view.get_opening_informations())
+        self.assertIsNotNone(json_contact.get_opening_informations())
 
         today = datetime.now()
         today_str = today.strftime("%Y-%m-%d")
@@ -210,24 +239,27 @@ class TestSectionContact(ImioSmartwebTestCase):
         self.json_contact["items"][0]["exceptional_closure"] = [
             {"date": today_str, "title": "Exceptional closure !"}
         ]
-        m.get(contact_search_url, text=json.dumps(self.json_contact))
-        clear_cache(self.request)
-        self.assertIsNotNone(contact_view.get_opening_informations())
+        json_contact = contact_view.get_contact_properties(
+            self.json_contact.get("items")[0]
+        )
+        self.assertIsNotNone(json_contact.get_opening_informations())
 
         today = datetime.now().strftime("%Y-%m-%d")
         self.json_contact["items"][0]["multi_schedule"][0]["dates"] = [
             {"end_date": tomorrow_str, "start_date": yesterday_str}
         ]
-        m.get(contact_search_url, text=json.dumps(self.json_contact))
-        clear_cache(self.request)
-        self.assertIsNotNone(contact_view.get_opening_informations())
+        json_contact = contact_view.get_contact_properties(
+            self.json_contact.get("items")[0]
+        )
+        self.assertIsNotNone(json_contact.get_opening_informations())
 
         self.json_contact["items"][0]["multi_schedule"][0]["dates"] = [
             {"end_date": yesterday_str, "start_date": yesterday_str}
         ]
-        m.get(contact_search_url, text=json.dumps(self.json_contact))
-        clear_cache(self.request)
-        self.assertIsNotNone(contact_view.get_opening_informations())
+        json_contact = contact_view.get_contact_properties(
+            self.json_contact.get("items")[0]
+        )
+        self.assertIsNotNone(json_contact.get_opening_informations())
 
     # {'afternoonend': '', 'afternoonstart': '', 'comment': 'vendredi : apéro à midi', 'morningend': '11:00', 'morningstart': '08:30'}
     def test_get_schedule_for_today(self):
@@ -402,40 +434,38 @@ class TestSectionContact(ImioSmartwebTestCase):
             type="imio.smartweb.SectionContact",
             title="My contact",
         )
-        contact_view = queryMultiAdapter((contact, self.request), name="view")
-        self.assertIsNone(contact_view.get_opening_informations())
         authentic_contact_uid = "2dc381f0fb584381b8e4a19c84f53b35"
-        contact.related_contact = authentic_contact_uid
+        contact.related_contacts = [authentic_contact_uid]
         contact_search_url = (
             "http://localhost:8080/Plone/@search?UID={}&fullobjects=1".format(
                 authentic_contact_uid
             )
         )
         m.get(contact_search_url, text=json.dumps(self.json_contact))
-        clear_cache(self.request)
+        json_contact = ContactProperties(self.json_contact.get("items")[0])
         with freeze_time("2021-06-30 12:20:00"):
-            schedule = contact_view.get_opening_informations()
+            schedule = json_contact.get_opening_informations()
             self.assertEqual(
                 "13:00 - 17:30 (Ouverture PM)",
-                contact_view.formatted_schedule(schedule),
+                json_contact.formatted_schedule(schedule),
             )
         with freeze_time("2021-07-07 12:20:00"):
-            schedule = contact_view.get_opening_informations()
+            schedule = json_contact.get_opening_informations()
             self.assertEqual(
                 "13:00 - 15:00 (Ouverture PM vacances)",
-                contact_view.formatted_schedule(schedule),
+                json_contact.formatted_schedule(schedule),
             )
         with freeze_time("2021-09-01 12:20:00"):
-            schedule = contact_view.get_opening_informations()
+            schedule = json_contact.get_opening_informations()
             self.assertEqual(
                 "13:00 - 17:30 (Ouverture PM)",
-                contact_view.formatted_schedule(schedule),
+                json_contact.formatted_schedule(schedule),
             )
         with freeze_time("2021-12-29 12:20:00"):
-            schedule = contact_view.get_opening_informations()
+            schedule = json_contact.get_opening_informations()
             self.assertEqual(
                 "13:00 - 15:00 (Ouverture PM vacances)",
-                contact_view.formatted_schedule(schedule),
+                json_contact.formatted_schedule(schedule),
             )
 
     @requests_mock.Mocker()
@@ -449,19 +479,17 @@ class TestSectionContact(ImioSmartwebTestCase):
             title="My contact",
         )
         contact.visible_blocks = ["titles", "gallery", "schedule"]
-        contact_view = queryMultiAdapter((contact, self.request), name="view")
-        self.assertIsNone(contact_view.get_opening_informations())
         authentic_contact_uid = "2dc381f0fb584381b8e4a19c84f53b35"
-        contact.related_contact = authentic_contact_uid
+        contact.related_contacts = [authentic_contact_uid]
         contact_search_url = (
             "http://localhost:8080/Plone/@search?UID={}&fullobjects=1".format(
                 authentic_contact_uid
             )
         )
         m.get(contact_search_url, text=json.dumps(json_contact_empty_schedule))
-        clear_cache(self.request)
         view = queryMultiAdapter((self.page, self.request), name="full_view")
-        is_empty = contact_view.is_empty_schedule()
+        json_contact = ContactProperties(json_contact_empty_schedule.get("items")[0])
+        is_empty = json_contact.is_empty_schedule()
         self.assertEqual(is_empty, True)
         self.assertNotIn('class="schedule"', view())
         json_contact_empty_schedule["items"][0].get("schedule")["monday"] = {
@@ -472,8 +500,8 @@ class TestSectionContact(ImioSmartwebTestCase):
             "comments": "",
         }
         m.get(contact_search_url, text=json.dumps(json_contact_empty_schedule))
-        clear_cache(self.request)
-        is_empty = contact_view.is_empty_schedule()
+        json_contact = ContactProperties(json_contact_empty_schedule.get("items")[0])
+        is_empty = json_contact.is_empty_schedule()
         self.assertEqual(is_empty, False)
         self.assertIn('class="schedule"', view())
 
@@ -486,7 +514,7 @@ class TestSectionContact(ImioSmartwebTestCase):
         )
         view = queryMultiAdapter((self.page, self.request), name="full_view")
         authentic_contact_uid = "2dc381f0fb584381b8e4a19c84f53b35"
-        contact.related_contact = authentic_contact_uid
+        contact.related_contacts = [authentic_contact_uid]
         contact_search_url = (
             "http://localhost:8080/Plone/@search?UID={}&fullobjects=1".format(
                 authentic_contact_uid
@@ -497,3 +525,43 @@ class TestSectionContact(ImioSmartwebTestCase):
         self.assertNotIn("contact_leadimage portrait", view())
         contact.is_in_portrait_mode = True
         self.assertIn("contact_leadimage portrait", view())
+
+    @requests_mock.Mocker()
+    def test_contact_modified(self, m):
+        contact = api.content.create(
+            container=self.page,
+            type="imio.smartweb.SectionContact",
+            title="My contact",
+        )
+        authentic_contact_uid = "2dc381f0fb584381b8e4a19c84f53b35"
+        contact.related_contacts = [authentic_contact_uid]
+        contact_search_url = (
+            "http://localhost:8080/Plone/@search?UID={}&fullobjects=1".format(
+                authentic_contact_uid
+            )
+        )
+        m.get(contact_search_url, text=json.dumps(self.json_contact))
+        contact_view = queryMultiAdapter((contact, self.request), name="view")
+
+        annotations = IAnnotations(contact)
+        self.assertIsNone(annotations.get(SECTION_ITEMS_HASH_KEY))
+
+        self.assertIsNotNone(contact_view.contacts())
+        hash_1 = annotations.get(SECTION_ITEMS_HASH_KEY)
+        self.assertIsNotNone(hash_1)
+        first_modification = self.page.ModificationDate()
+
+        sleep(1)
+        m.get(contact_search_url, text=json.dumps(self.json_no_contact))
+        self.assertIsNone(contact_view.contacts())
+        next_modification = self.page.ModificationDate()
+        hash_2 = annotations.get(SECTION_ITEMS_HASH_KEY)
+        self.assertNotEqual(hash_1, hash_2)
+        self.assertNotEqual(first_modification, next_modification)
+
+        sleep(1)
+        self.assertIsNone(contact_view.contacts())
+        last_modification = self.page.ModificationDate()
+        hash_3 = annotations.get(SECTION_ITEMS_HASH_KEY)
+        self.assertEqual(hash_2, hash_3)
+        self.assertEqual(next_modification, last_modification)
