@@ -1,5 +1,6 @@
 # -*- coding: utf-8 -*-
 
+from AccessControl.unauthorized import Unauthorized
 from bs4 import BeautifulSoup
 from collective.geolocationbehavior.geolocation import IGeolocatable
 from functools import reduce
@@ -110,6 +111,39 @@ class TestSections(ImioSmartwebTestCase):
             "https://www.youtube.com/embed/_dOAthafoGQ?feature=oembed", embedded_video
         )
 
+    def test_external_content_section(self):
+        setRoles(self.portal, TEST_USER_ID, ["Contributor"])
+        with self.assertRaises(Unauthorized):
+            api.content.create(
+                container=self.page,
+                type="imio.smartweb.SectionExternalContent",
+                title="Section External Content",
+            )
+        setRoles(self.portal, TEST_USER_ID, ["Manager"])
+        section = api.content.create(
+            container=self.page,
+            type="imio.smartweb.SectionExternalContent",
+            title="Section External Content",
+        )
+        # section.external_content_url = (
+        #     "https://app.eaglebe.com/fr-be/map/la%20louvi%C3%A8re"
+        # )
+        # view = queryMultiAdapter((section, self.request), name="view")
+        # embedded_content = view.get_embed_external_content()
+        # self.assertIn("iframe", embedded_content)
+        # self.assertIn('class="eaglebe"', embedded_content)
+        # self.assertIn('scrolling="no"', embedded_content)
+        # self.assertIn(
+        #     "https://app.eaglebe.com/fr-be/map/la%20louvi%C3%A8re", embedded_content
+        # )
+
+        section.external_content_url = "http://www.perdu.com"
+        view = queryMultiAdapter((section, self.request), name="view")
+        embedded_content = view.get_embed_external_content()
+        self.assertNotIn("iframe", embedded_content)
+        self.assertNotIn("class='eaglebe'", embedded_content)
+        self.assertIn('<p class="unknow_service">Unknow service</p>', embedded_content)
+
     def test_map_section(self):
         section = api.content.create(
             container=self.page,
@@ -183,7 +217,7 @@ class TestSections(ImioSmartwebTestCase):
         items = view.items()
         self.assertEqual(len(items), 2)
         self.assertEqual(len(items[0]), 3)
-        self.assertEqual(reduce(lambda count, l: count + len(l), items, 0), 6)
+        self.assertEqual(reduce(lambda count, r: count + len(r), items, 0), 6)
         section_collection.nb_results_by_batch = 1
         section_collection.max_nb_batches = 4
         view = queryMultiAdapter((section_collection, self.request), name="table_view")
@@ -534,7 +568,7 @@ class TestSections(ImioSmartwebTestCase):
         self.assertEqual(view.background_style(section), "")
         section.background_image = NamedBlobImage(**make_named_image())
         self.assertIn(
-            "background-image:url(http://nohost/plone/page/section-text/@@images/",
+            "background-image:url(http://nohost/plone/page/section-text/@@images/background_image-768",
             view.background_style(section),
         )
 
