@@ -14,10 +14,14 @@ from Products.CMFPlone.utils import base_hasattr
 from zope.component import getSiteManager
 from zope.component import queryMultiAdapter
 
+import hashlib
 import json
+import logging
 import os
 import requests
 
+logger = logging.getLogger("imio.smartweb.core")
+
 
 def get_category(context):
     if not base_hasattr(context, "category_name"):
@@ -51,12 +55,15 @@ def concat_voca_title(title1, title2):
     return "{0} - {1}".format(title1, title2)
 
 
-def get_json(url, auth=None):
+def get_json(url, auth=None, timeout=5):
     headers = {"Accept": "application/json"}
     if auth is not None:
         headers["Authorization"] = auth
     try:
-        response = requests.get(url, headers=headers, timeout=5)
+        response = requests.get(url, headers=headers, timeout=timeout)
+    except requests.exceptions.Timeout:
+        logger.warning(f"Timeout raised for requests : {url}")
+        return None
     except Exception:
         return None
     if response.status_code != 200:
@@ -86,6 +93,10 @@ def get_wca_token(client_id, client_secret):
     return "Bearer {0}".format(id_token)
 
 
+def hash_md5(text):
+    return hashlib.md5(text.encode()).hexdigest()
+
+
 def safe_html(html):
     if not html:
         return
@@ -130,18 +141,16 @@ def get_scale_url(context, request, fieldname, scale):
         return scale.url
     else:
         # get scale url on a brain
+        # In this case, we need a modification hash to handle croppings, because
+        # catalog does not handle them correctly.
+        # See https://github.com/collective/plone.app.imagecropping/issues/129
         brain = context
-        if not getattr(brain, "image_scales", None):
+        if fieldname == "image" and not brain.has_leadimage:
             return ""
-        if fieldname not in brain.image_scales:
-            return ""
-        try:
-            data = brain.image_scales[fieldname][0]["scales"][scale]
-        except (KeyError, IndexError):
-            return ""
-        url = (
-            data["download"]
-            if data["download"].startswith("http")
-            else f"{brain.getURL()}/{data['download']}"
-        )
+        modification_date = brain.ModificationDate
+        if callable(modification_date):
+            # brain in content listing for example
+            modification_date = modification_date()
+        modified_hash = hash_md5(modification_date)
+        url = f"{brain.getURL()}/@@images/{fieldname}/{scale}?cache_key={modified_hash}"
         return url
