@@ -75,7 +75,7 @@ const NewsView = (props) => {
 
     // set batch
     const loadMore = () => {
-        setBatchStart((batchStart) => batchStart + props.batchSize);
+        setBatchStart((batchStart) => batchStart + parseInt(props.batchSize));
         setLoadMoreLaunch(true);
     };
     // Update filters Batch
@@ -128,8 +128,8 @@ const NewsView = (props) => {
                                         <p className="r-results-numbers">
                                             <span>{contactNumber}</span>{" "}
                                             {contactNumber > 1
-                                                ? <Translate text=' Actualités trouvées' />
-                                                : <Translate text=' Actualité trouvée' />}
+                                                ? <Translate text='Actualités trouvées' />
+                                                : <Translate text='Actualité trouvée' />}
                                         </p>
                                     ) : (
                                         <p className="r-results-numbers"><Translate text='Aucun résultat' /></p>
